@@ -30,9 +30,8 @@ convertWikipediaTimezoneTable <- function() {
   # 4.  Comments; present if and only if the country has multiple rows.
   
   # Get the raw html from the url
-  wikiDoc <- rvest::html(url)
-  ###wikiDoc <- rvest::read_html(url) # When rvest 0.3.x is default in more places.
-  
+  wikiDoc <- xml2::read_html(url)
+
   # Get a list of tables in the document
   tables <- rvest::html_nodes(wikiDoc, "table")
   
